@@ -17,7 +17,9 @@ extern "C" {
 #endif
 
 // This module is for GCC x86 and x64.
-#if !defined(LIBYUV_DISABLE_X86) && (defined(__x86_64__) || defined(__i386__))
+#if !defined(LIBYUV_DISABLE_X86) &&               \
+    (defined(__x86_64__) || defined(__i386__)) && \
+    !defined(LIBYUV_ENABLE_ROWWIN)
 
 // Transpose 8x8. 32 or 64 bit, but not NaCL for 64 bit.
 #if defined(HAS_TRANSPOSEWX8_SSSE3)
@@ -26,11 +28,11 @@ void TransposeWx8_SSSE3(const uint8_t* src,
                         uint8_t* dst,
                         int dst_stride,
                         int width) {
-  asm volatile (
+  asm volatile(
       // Read in the data from the source pointer.
       // First round of bit swap.
       LABELALIGN
-      "1:                                        \n"
+      "1:          \n"
       "movq        (%0),%%xmm0                   \n"
       "movq        (%0,%3),%%xmm1                \n"
       "lea         (%0,%3,2),%0                  \n"
@@ -116,11 +118,11 @@ void TransposeWx8_Fast_SSSE3(const uint8_t* src,
                              uint8_t* dst,
                              int dst_stride,
                              int width) {
-  asm volatile (
+  asm volatile(
       // Read in the data from the source pointer.
       // First round of bit swap.
       LABELALIGN
-      "1:                                        \n"
+      "1:          \n"
       "movdqu      (%0),%%xmm0                   \n"
       "movdqu      (%0,%3),%%xmm1                \n"
       "lea         (%0,%3,2),%0                  \n"
@@ -261,11 +263,11 @@ void TransposeUVWx8_SSE2(const uint8_t* src,
                          uint8_t* dst_b,
                          int dst_stride_b,
                          int width) {
-  asm volatile (
+  asm volatile(
       // Read in the data from the source pointer.
       // First round of bit swap.
       LABELALIGN
-      "1:                                        \n"
+      "1:          \n"
       "movdqu      (%0),%%xmm0                   \n"
       "movdqu      (%0,%4),%%xmm1                \n"
       "lea         (%0,%4,2),%0                  \n"
@@ -391,9 +393,9 @@ void Transpose4x4_32_SSE2(const uint8_t* src,
                           uint8_t* dst,
                           int dst_stride,
                           int width) {
-  asm volatile (
+  asm volatile(
       // Main loop transpose 4x4.  Read a column, write a row.
-      "1:                                        \n"
+      "1:          \n"
       "movdqu      (%0),%%xmm0                   \n"  // a b c d
       "movdqu      (%0,%3),%%xmm1                \n"  // e f g h
       "lea         (%0,%3,2),%0                  \n"  // src += stride * 2
@@ -447,9 +449,9 @@ void Transpose4x4_32_AVX2(const uint8_t* src,
                           uint8_t* dst,
                           int dst_stride,
                           int width) {
-  asm volatile (
+  asm volatile(
       // Main loop transpose 2 blocks of 4x4.  Read a column, write a row.
-      "1:                                        \n"
+      "1:          \n"
       "vmovdqu     (%0),%%xmm0                   \n"  // a b c d
       "vmovdqu     (%0,%3),%%xmm1                \n"  // e f g h
       "lea         (%0,%3,2),%0                  \n"  // src += stride * 2
@@ -484,7 +486,7 @@ void Transpose4x4_32_AVX2(const uint8_t* src,
       "sub         %4,%1                         \n"
       "sub         $0x8,%2                       \n"
       "jg          1b                            \n"
-      "vzeroupper                                \n"
+      "vzeroupper  \n"
       : "+r"(src),                     // %0
         "+r"(dst),                     // %1
         "+rm"(width)                   // %2
